#
# Makefile Template for Tessy
# Compiler: Keil C51
# Debugger: Keil Vision
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
define TS_DEFINE
$(foreach define,$(subst ;, ,$(1)),DF($(define)))
endef

TS_INC_SEPARATOR :=,
define TS_INCLUDE
$(subst ;,$(TS_INC_SEPARATOR),$(1))
endef

TMP_LINK_FILE := ts_$(TESTOBJECT).lin
define TS_ADD_TO_LINKER_FILE
$(if $(1),$(file >>$(TMP_LINK_FILE),$(1)))
endef
COMMA :=,
define TS_ADD_ENTRY_TO_LINKER_FILE
$(if $(1),$(file >>$(TMP_LINK_FILE),$(1)$(COMMA)))
endef
define TS_LIST
$(foreach var,$(2),$(call $(1),$(var)))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
KEIL_HOME       := $(shell ts_pathname -rs '$(COMPILER_INSTALL_PATH)')
UVSC_HOME       := $(shell ts_pathname -rs '$(TARGET_INSTALL_PATH)')
MODULE_PATH_DOS := $(shell ts_pathname -s '$(MODULE_PATH_DOS)')

TS_NAME         := TS_UVISION
IDE_NAME        := uvision_uvsc
COMPANY_NAME    := keil
PROCESSOR_NAME  := c51

all	   : master slave
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)

master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)


#

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE     := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE     := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
#
S_INCLUDES		:= $(TESSY_SYS_DOS)\include\tessy\comm
S_ASM_INCLUDES :=	$(KEIL_HOME)\ASM
S_COMP_OPTIONS := LARGE DEBUG OT "(0)" BROWSE WARNINGLEVEL "(0)" REGPARMS NOPR OE DF(TS_SLAVE)
S_ASM_OPTIONS  := LARGE
S_LINK_OPTIONS := RECURSIONS(0)

ifeq ("true","$(C51_ENHANCED_LINKER_LOCATOR)")
S_CC           := $(KEIL_HOME)/BIN/CX51.EXE
S_ASM          := $(KEIL_HOME)/BIN/AX51.EXE
S_LINK         := $(KEIL_HOME)/BIN/LX51.EXE
else
S_CC           := $(KEIL_HOME)/BIN/C51.EXE
S_ASM          := $(KEIL_HOME)/BIN/A51.EXE
S_LINK         := $(KEIL_HOME)/BIN/BL51.EXE
endif
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_t_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_t_usr$(OBJFILE_EXTENSION)

LOFLAGS			:= DW(16)
COMMA				:=	,


#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) "$<" $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) \
		INCDIR($(S_INCLUDES)$(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER)))) OBJECT "($@)"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

#
# COPY USERCODE / STUBS / DRIVER
#
$(MODULE_PATH_DOS)\ts_t_usr.c : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	@ts_cp $< $@

$(MODULE_PATH_DOS)\ts_t_stubs.c : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	@ts_cp $< $@

$(MODULE_PATH_DOS)\ts_t_s.c : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@ts_cp $< $@


#
# COMPILE USERCODE / STUBS
#




$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_t_usr.c
	$(S_CC) $< $(S_COMP_OPTIONS) INCDIR "($(S_INCLUDES))" OBJECT "($@)"

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_t_stubs.c
	$(S_CC) $< $(S_COMP_OPTIONS) INCDIR "($(S_INCLUDES))" OBJECT "($@)"

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)




#
# COMPILE/LINK SLAVE
#

$(MODULE_PATH_DOS)\ts_start$(OBJFILE_EXTENSION) : $(STARTUP_FILE)
	$(S_ASM) "$<" SET "($(S_ASM_OPTIONS))" EP ID "($(S_ASM_INCLUDES))" OBJECT "($@)" NOPR

$(MODULE_PATH_DOS)\ts_t_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_t_s.c
	@echo *
	@echo ***** Copying Header Files *****
	@ts_cp $(S_INCLUDES)\tsteval.h $(MODULE_PATH_DOS)
	@ts_cp $(S_INCLUDES)\tstcomm_base.h $(MODULE_PATH_DOS)
	@ts_cp $(S_INCLUDES)\tessy_types.h $(MODULE_PATH_DOS)
	@echo ***** Compiling Slave *****
	$(S_CC) $< $(S_COMP_OPTIONS) INCDIR($(S_INCLUDES)) OBJECT "($@)"

$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_t_s$(OBJFILE_EXTENSION) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(MODULE_PATH_DOS)\ts_start$(OBJFILE_EXTENSION) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(file >$(TMP_LINK_FILE))
	$(call TS_ADD_ENTRY_TO_LINKER_FILE,$(MODULE_PATH_DOS)\ts_start$(OBJFILE_EXTENSION))
	$(call TS_LIST,TS_ADD_ENTRY_TO_LINKER_FILE,$(S_OBJECTS))
	$(call TS_ADD_ENTRY_TO_LINKER_FILE,$(MODULE_PATH_DOS)\ts_t_s$(OBJFILE_EXTENSION))
	$(call TS_LIST,TS_ADD_ENTRY_TO_LINKER_FILE,$(S_SRC_OBJECTS))
	$(call TS_ADD_ENTRY_TO_LINKER_FILE,$(S_UC_OBJECT))
	$(call TS_ADD_ENTRY_TO_LINKER_FILE,$(S_STUB_OBJECT))
	$(call TS_LIST,TS_ADD_ENTRY_TO_LINKER_FILE,$(USER_LINK_OPTIONS))
	$(call TS_ADD_TO_LINKER_FILE,$(LIBRARY))
	$(call TS_ADD_TO_LINKER_FILE,TO $@)
	$(call TS_ADD_TO_LINKER_FILE,$(LOFLAGS))
	$(call TS_ADD_TO_LINKER_FILE,$(S_LINK_OPTIONS))
	@-$(S_LINK) "@$(TMP_LINK_FILE)" > error.log || [ -f "$@" ]

#####################################################################
#END_TARGETS
#####################################################################
